bayespy.nodes.GaussianGamma.initialize_from_parameters
======================================================

.. currentmodule:: bayespy.nodes

.. automethod:: GaussianGamma.initialize_from_parameters